#
# spec file for package jackson-dataformats-text
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jackson-dataformats-text
Version:        2.17.1
Release:        1.1
Summary:        Jackson standard text-format data format backends
License:        Apache-2.0
URL:            https://github.com/FasterXML/jackson-dataformats-text
Source0:        https://github.com/FasterXML/jackson-dataformats-text/archive/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-annotations) >= 2.17
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core) >= 2.17
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind) >= 2.17
BuildRequires:  mvn(com.fasterxml.jackson:jackson-base:pom:)
BuildRequires:  mvn(com.google.code.maven-replacer-plugin:replacer)
BuildRequires:  mvn(de.jflex:jflex-maven-plugin)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.yaml:snakeyaml)
BuildArch:      noarch

%description
Parent pom for Jackson text-format dataformats.

%package -n jackson-dataformat-csv
Summary:        Support for reading and writing CSV-encoded data via Jackson abstractions

%description -n jackson-dataformat-csv
Jackson data format module for reading and writing CSV encoded data, either
as "raw" data (sequence of String arrays), or via data binding to/from Java
Objects (POJOs).

%package -n jackson-dataformat-properties
Summary:        Support for reading and writing content of "Java Properties" files

%description -n jackson-dataformat-properties
Jackson data format module that supports reading and writing Java Properties
files, using naming convention to determine implied structure (by default
assuming dotted notation, but configurable from non-nested to other
separators).

%package -n jackson-dataformat-yaml
Summary:        Support for reading and writing YAML-encoded data via Jackson abstractions

%description -n jackson-dataformat-yaml
Jackson extension component for reading and writing YAML encoded data.
SnakeYAML library is used for low-level YAML parsing. This project adds
necessary abstractions on top to make things work with other Jackson
functionality.

%package -n jackson-dataformat-toml
Summary:        Support for reading and writing TOML-encoded data via Jackson abstractions

%description -n jackson-dataformat-toml
Jackson extension component for reading and writing TOML encoded data.
This project adds necessary abstractions on top to make things work
with other Jackson functionality.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%pom_remove_plugin -r :gradle-module-metadata-maven-plugin
%pom_remove_plugin -r :moditect-maven-plugin

cp -p yaml/src/main/resources/META-INF/{NOTICE,LICENSE} .
sed -i 's/\r//' LICENSE NOTICE

%{mvn_file} ":{*}" jackson-dataformats/@1

%build
%{mvn_build} -sf -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles-jackson-dataformats-text
%doc README.md release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-csv -f .mfiles-jackson-dataformat-csv
%doc csv/README.md csv/release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-properties -f .mfiles-jackson-dataformat-properties
%doc properties/README.md properties/release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-yaml -f .mfiles-jackson-dataformat-yaml
%doc yaml/README.md yaml/release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-toml -f .mfiles-jackson-dataformat-toml
%doc toml/README.md
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Mon May 20 2024 Gus Kenion <gus.kenion@suse.com>
- Update to 2.17.1
  * No changes since 2.17.0
- Includes changes from 2.17.0
  * #45: (csv) Allow skipping ending line break
    (`CsvGenerator.Feature.WRITE_LINEFEED_AFTER_LAST_ROW`)
    (proposed by Mathieu L)
  * #454: (yaml) Unexpected `NumberFormatException` in `YAMLParser`
    (fix contributed by Arthur C)
  * #456: (yaml) Support max Read/Write nesting depth limits
    (`StreamReadConstraints`/ `StreamWriteConstraints`) for YAML
  * #465: (yaml) YAML: consider starting `#` and ending `:` as
    quotable characters (contributed by Michael E)
* Fri Mar  8 2024 Gus Kenion <gkenion@suse.com>
- Update to version 2.16.1
  * Resolve CVE-2023-3894, bsc#1214111
  * 2.16.1 (24-Dec-2023)
    + #445: (yaml) YAMLParser throws unexpected NullPointerException
    in certain number parsing cases
  * 2.16.0 (15-Nov-2023)
    + #198: (csv) Support writing numbers as quoted Strings with
    CsvGenerator.Feature.ALWAYS_QUOTE_NUMBERS
    + #422: (csv) Add removeColumn() method in CsvSchema.Builder
    + #438: (csv) BigInteger and BigDecimal are quoted if
    CsvGenerator.Feature.ALWAYS_QUOTE_STRINGS enabled
    + #400: (yaml) IllegalArgumentException when attempting to
    decode invalid UTF-8 surrogate by SnakeYAML
    + #406: (yaml) NumberFormatException from SnakeYAML due to int
    overflow for corrupt YAML version
    + #435: (yaml) Minor parsing validation miss: tagged as int,
    exception on underscore-only values
    + #437: (yaml) Update SnakeYAML dependency to 2.2
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Mon Aug 21 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 2.15.2
  * No changes since 2.15.1
  * 2.15.1 (16-May-2023)
    + #404: (yaml) Cannot serialize YAML with Deduction-Based
    Polymorphism
  * 2.15.0 (23-Apr-2023)
    + #373: (yaml) Positive numbers with plus sign not quoted
    correctly with 'ALWAYS_QUOTE_NUMBERS_AS_STRINGS'
    + #387: (toml) Stack overflow (50083) found by OSS-Fuzz
    (bsc#1214111, CVE-2023-3894)
    + #388: (yaml) Add
    'YAMLParser.Feature.PARSE_BOOLEAN_LIKE_WORDS_AS_STRINGS' to
    allow parsing "boolean" words as strings instead of booleans
    + #390: (yaml) Upgrade to Snakeyaml 2.0 (resolves CVE-2022-1471,
    bsc#1205944)
    + #411: (toml) Fuzzer-found issue #57237 (buffer boundary
    condition)
    + #415: (yaml) Use 'LoaderOptions.allowDuplicateKeys' to enforce
    duplicate key detection
  * 2.14.3 (05-May-2023)
    + #378: Some artifacts missing 'NOTICE', 'LICENSE' files
  * 2.14.2 (28-Jan-2023)
    + #356: (toml) Fix TOML parse failure when number token hits
    buffer edge
    + #370: (yaml) Replace use of deprecated constructor of
    SnakeYAML ParserImpl
  * 2.14.1 (21-Nov-2022)
    + #352: Disabling
    'CsvParser.Feature.FAIL_ON_MISSING_HEADER_COLUMNS' has no
    effect
  * 2.14.0 (05-Nov-2022)
    + #169: (properties) Need a way to escape dots in property keys
    (add path separator configuration)
    + #244: (yaml) Add 'YAMLGenerator.Feature.ALLOW_LONG_KEYS' to
    allow writing keys longer than 128 characters (default)
    + #285: (csv) Missing columns from header line (compare to
    'CsvSchema') not detected when reordering columns (add
    'CsvParser.Feature.FAIL_ON_MISSING_HEADER_COLUMNS')
    + #297: (csv) CSV schema caching POJOs with different views
    + #314: (csv) Add fast floating-point parsing, generation
    support
    + #335/#346: (yaml) Update to SnakeYAML 1.33
    + #337: (yaml) Allow overriding of file size limit for
    YAMLParser by exposing SnakeYAML 'LoaderOptions'
    + #345: (yaml) Support configuring SnakeYAML DumperOptions
    directly
    + #351: (csv) Make CSVDecoder use lazy parsing of
    BigInteger/BigDecimal
    + (yaml) Fixes to number decoding based on oss-fuzz findings
  * 2.13.5 (23-Jan-2023)
    + #343: Incorrect output buffer boundary check in 'CsvEncoder'
  * 2.13.4 (03-Sep-2022)
    + #329: (yaml) Update to SnakeYAML 1.31
* Tue Jun 14 2022 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jackson-dataformats-text 2.13.3
